#!/bin/sh
# 
# This script will be used to install a DSA mediator into Impact for various
# unix platforms.
#
# Three parameters have to be set in this script. The name of the DSA, the
# mode of the DSA and name of the jar file for DIRECT mode dsas
#
# To run in console mode, pass in the argument "-console"

INITIAL_MEMORY="32M"

USAGE="installMediator.sh [-console]"
CONSOLE=""

case "$1" in
-console )
	CONSOLE=" -i console"
	;;
-* )	echo $USAGE
	exit 1
	;;
esac

# We need IMPACT_HOME to be set because we're going to use its jvm.
if [ -z "$IMPACT_HOME" ]; then
        echo "IMPACT_HOME environment variable not set, using /opt/netcool/impact."
	IMPACT_HOME=/opt/netcool/impact export IMPACT_HOME
fi

# Now we need to determine the RUNTIME from nci_server.
# This is quite ugly....but we are having problems with the RUNTIME
# being hard coded in the DSAs.
eval `grep "RUNTIME=" $IMPACT_HOME/bin/nci_server`

if [ -z "$RUNTIME" ]; then
        echo "RUNTIME could not be determined from $IMPACT_HOME/bin/nci_server script. "
	echo "Please check that $IMPACT_HOME is set to a valid Impact installation.  Exiting."
        exit 1
fi


# Make sure the DSA name is properly set here
DSA_INSTALL_NAME=snmpdsa export DSA_INSTALL_NAME

# Make sure the DSA mode is set here. It is either DIRECT or CORBA mode.
DSA_WORKING_MODE=DIRECT  export DSA_WORKING_MODE

# Make sure the JAR file name for the dsa is set here
DSA_INSTALL_JAR_NAME=snmpdsa2007May23.jar export DSA_INSTALL_JAR_NAME

# What OS are we running ?
#
UNAME_S=`uname -s`

echo "Installing ${DSA_INSTALL_NAME} for ${UNAME_S}"

# Figure out where java lives.  For this, we need some information
# about the Impact installation so source the proper files.
# Below, we force the installer to use the one within Impact
# using the LAX_VM command line option.
. ${IMPACT_HOME}/bin/.nci_wrapper
. ${IMPACT_HOME}/platform/${ARCH}/runtime_def_${RUNTIME}

case ${UNAME_S} in
SunOS )
  cd installExecFiles/solaris
  ./meddsa.bin  LAX_VM ${VM_RUNTIME} ${CONSOLE};;
HP-UX )
  cd installExecFiles/hp
  ./meddsa.bin  LAX_VM ${VM_RUNTIME} ${CONSOLE};;
Linux )
  cd installExecFiles/linux
  ./meddsa.bin  LAX_VM ${VM_RUNTIME} ${CONSOLE};;
AIX )
  cd installExecFiles/aix
  ./meddsa.bin  LAX_VM ${VM_RUNTIME} ${CONSOLE};;
* )
	Error "Unknown architecture $UNAME_S" ;;
esac
